Learn R Programming

tinyplot (version 0.8.0)

draw_facet_window: Draw facet windows

Description

Internal functions called from tinyplot in order to draw the plot window with different facets, grids, axes, etc.

facet_layout determines the layout of the facets, based on a set of inputs.

draw_facet_window is the main workhorse function for setting the exterior plot elements as part of a tinyplot call, including adjustment of margins for dynamic themes, etc.

Usage

draw_facet_window(
  add,
  cex_fct_adj,
  facet.args,
  facet_newlines,
  facet_font,
  facet_rect,
  facet_text,
  facet_col,
  facet_bg,
  facet_border,
  facet,
  facets,
  ifacet,
  nfacets,
  nfacet_cols,
  nfacet_rows,
  facet_blank = FALSE,
  axes,
  flip,
  frame.plot,
  oxaxis,
  oyaxis,
  xlabs,
  xlim,
  null_xlim,
  xaxt,
  xaxs,
  xaxb,
  xaxl,
  xaxr = NULL,
  xpad = NULL,
  ylabs,
  ylim,
  null_ylim,
  yaxt,
  yaxs,
  yaxb,
  yaxl,
  yaxr = NULL,
  ypad = NULL,
  xpad_user = NULL,
  ypad_user = NULL,
  rev_x = FALSE,
  rev_y = FALSE,
  xlim_partial = NULL,
  ylim_partial = NULL,
  facet_labs = NULL,
  asp,
  log,
  dots,
  draw,
  grid,
  has_legend,
  main,
  sub,
  cap,
  type,
  type_hints = NULL,
  xlab,
  x,
  xmax,
  xmin,
  ylab,
  y,
  ymax,
  ymin,
  tpars = NULL,
  dynmar_computed = NULL,
  dl_overshoot = 0
)

facet_relevel(settings)

facet_layout(settings)

Arguments

settings

A list of settings as created by tinyplot().

Details

facet_relevel implements facet.args$drop.levels: each free facet keeps only the categories it actually uses, re-levelled as if the panel's data had been passed through factor() on its own. Positions are shifted rather than recomputed, so a row's offset within its category (dodge, jitter, boxplot group offsets) and any rectangle width around it survive untouched.